@@ -47,9 +47,13 @@ class BubbleChartDataPoint(ScatterChartDataPoint):
         'effect_format': 'EffectFormat',
         'three_d_format': 'ThreeDFormat',
         'line_format': 'LineFormat',
+        'type': 'str',
         'x_value': 'float',
         'y_value': 'float',
-        'bubble_size': 'float'
+        'x_value_formula': 'str',
+        'y_value_formula': 'str',
+        'bubble_size': 'float',
+        'bubble_size_formula': 'str'
     }
 
     attribute_map = {
@@ -57,21 +61,31 @@ class BubbleChartDataPoint(ScatterChartDataPoint):
         'effect_format': 'effectFormat',
         'three_d_format': 'threeDFormat',
         'line_format': 'lineFormat',
+        'type': 'type',
         'x_value': 'xValue',
         'y_value': 'yValue',
-        'bubble_size': 'bubbleSize'
+        'x_value_formula': 'xValueFormula',
+        'y_value_formula': 'yValueFormula',
+        'bubble_size': 'bubbleSize',
+        'bubble_size_formula': 'bubbleSizeFormula'
     }
 
     type_determiners = {
+        'type': 'Bubble',
     }
 
-    def __init__(self, fill_format=None, effect_format=None, three_d_format=None, line_format=None, x_value=None, y_value=None, bubble_size=None):  # noqa: E501
+    def __init__(self, fill_format=None, effect_format=None, three_d_format=None, line_format=None, type='Bubble', x_value=None, y_value=None, x_value_formula=None, y_value_formula=None, bubble_size=None, bubble_size_formula=None):  # noqa: E501
         """BubbleChartDataPoint - a model defined in Swagger"""  # noqa: E501
-        super(BubbleChartDataPoint, self).__init__(fill_format, effect_format, three_d_format, line_format, x_value, y_value)
+        super(BubbleChartDataPoint, self).__init__(fill_format, effect_format, three_d_format, line_format, type, x_value, y_value, x_value_formula, y_value_formula)
 
         self._bubble_size = None
+        self._bubble_size_formula = None
+        self.type = 'Bubble'
 
-        self.bubble_size = bubble_size
+        if bubble_size is not None:
+            self.bubble_size = bubble_size
+        if bubble_size_formula is not None:
+            self.bubble_size_formula = bubble_size_formula
 
     @property
     def bubble_size(self):
@@ -95,6 +109,28 @@ class BubbleChartDataPoint(ScatterChartDataPoint):
         """
         self._bubble_size = bubble_size
 
+    @property
+    def bubble_size_formula(self):
+        """Gets the bubble_size_formula of this BubbleChartDataPoint.  # noqa: E501
+
+        Spreadsheet formula in A1-style.  # noqa: E501
+
+        :return: The bubble_size_formula of this BubbleChartDataPoint.  # noqa: E501
+        :rtype: str
+        """
+        return self._bubble_size_formula
+
+    @bubble_size_formula.setter
+    def bubble_size_formula(self, bubble_size_formula):
+        """Sets the bubble_size_formula of this BubbleChartDataPoint.
+
+        Spreadsheet formula in A1-style.  # noqa: E501
+
+        :param bubble_size_formula: The bubble_size_formula of this BubbleChartDataPoint.  # noqa: E501
+        :type: str
+        """
+        self._bubble_size_formula = bubble_size_formula
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
