@@ -45,6 +45,7 @@ class TiffExportOptions(ImageExportOptionsBase):
     swagger_types = {
         'default_regular_font': 'str',
         'font_fallback_rules': 'list[FontFallbackRule]',
+        'font_subst_rules': 'list[FontSubstRule]',
         'format': 'str',
         'height': 'int',
         'width': 'int',
@@ -63,6 +64,7 @@ class TiffExportOptions(ImageExportOptionsBase):
     attribute_map = {
         'default_regular_font': 'defaultRegularFont',
         'font_fallback_rules': 'fontFallbackRules',
+        'font_subst_rules': 'fontSubstRules',
         'format': 'format',
         'height': 'height',
         'width': 'width',
@@ -82,9 +84,9 @@ class TiffExportOptions(ImageExportOptionsBase):
         'format': 'tiff',
     }
 
-    def __init__(self, default_regular_font=None, font_fallback_rules=None, format='tiff', height=None, width=None, compression=None, dpi_x=None, dpi_y=None, show_hidden_slides=None, pixel_format=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
+    def __init__(self, default_regular_font=None, font_fallback_rules=None, font_subst_rules=None, format='tiff', height=None, width=None, compression=None, dpi_x=None, dpi_y=None, show_hidden_slides=None, pixel_format=None, notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None, show_comments_by_no_author=None):  # noqa: E501
         """TiffExportOptions - a model defined in Swagger"""  # noqa: E501
-        super(TiffExportOptions, self).__init__(default_regular_font, font_fallback_rules, format, height, width)
+        super(TiffExportOptions, self).__init__(default_regular_font, font_fallback_rules, font_subst_rules, format, height, width)
 
         self._compression = None
         self._dpi_x = None
